@@ -74,10 +74,7 @@ func trackSomethingErrored(pw Writer, tracker *Tracker) {
 			if tracker.value+incrementPerCycle > total {
 				tracker.MarkAsErrored()
 			} else {
-				tracker.Increment(incrementPerCycle)
-			}
-			if tracker.Value() >= total {
-				tracker.MarkAsErrored()
+				tracker.IncrementWithError(incrementPerCycle)
 			}
 		}
 	}
@@ -108,6 +105,7 @@ func trackSomethingIndeterminate(pw Writer, tracker *Tracker) {
 
 func renderAndWait(pw Writer, autoStop bool) {
 	go pw.Render()
+	go pw.Render() // this call should be a no-op
 	time.Sleep(time.Millisecond * 100)
 	for pw.IsRenderInProgress() {
 		if pw.LengthActive() == 0 {
